From 044cf9fb8597c6507a249d17cea443305881c4f6 Mon Sep 17 00:00:00 2001
From: Josh Soref <2119212+jsoref@users.noreply.github.com>
Date: Sat, 7 Dec 2024 21:52:54 -1000
Subject: chore: fix spelling
* a
* acceleration
* addition
* altogether
* api clients
* artist
* associated
* bandwidth
* cannot
* capabilities
* case-insensitive
* case-sensitive
* configuration
* delimiter
* dependent
* diacritics
* directors
* enable
* explicitly
* filters
* finish
* have
* hierarchy
* implicit
* include
* information
* into
* its
* keepalive
* localization
* macos
* manual
* matching
* metadata
* nonexistent
* options
* overridden
* parsed
* parser
* playback
* preferring
* processes
* processing
* provider
* ratings
* retrieval
* running
* segments
* separate
* should
* station
* subdirectories
* superseded
* supported
* system
* than
* the
* throws
* transpose
* valid
* was
link: forum or chat rooms
Signed-off-by: Josh Soref <2119212+jsoref@users.noreply.github.com>
---
MediaBrowser.Model/Plugins/PluginStatus.cs | 7 ++++++-
1 file changed, 6 insertions(+), 1 deletion(-)
(limited to 'MediaBrowser.Model/Plugins/PluginStatus.cs')
diff --git a/MediaBrowser.Model/Plugins/PluginStatus.cs b/MediaBrowser.Model/Plugins/PluginStatus.cs
index bd420d7b4e..9c7a8f0c2c 100644
--- a/MediaBrowser.Model/Plugins/PluginStatus.cs
+++ b/MediaBrowser.Model/Plugins/PluginStatus.cs
@@ -34,7 +34,12 @@ namespace MediaBrowser.Model.Plugins
Malfunctioned = -3,
///
- /// This plugin has been superceded by another version.
+ /// This plugin has been superseded by another version.
+ ///
+ Superseded = -4,
+
+ ///
+ /// [DEPRECATED] See Superseded.
///
Superceded = -4,
--
cgit v1.2.3